BOOST_PP_REPEAT_z_macros

This is a list, based on functionality, of the macros which have an alternate _z name, representing a reentry into the BOOST_PP_REPEAT looping construct:
array

- BOOST_PP_ARRAY_POP_BACK_Z
- BOOST_PP_ARRAY_POP_FRONT_Z

repetition

- BOOST_PP_DEDUCE_Z
- BOOST_PP_ENUM_BINARY_PARAMS_Z
- BOOST_PP_ENUM_PARAMS_Z
- BOOST_PP_ENUM_SHIFTED_BINARY_PARAMS_Z
- BOOST_PP_ENUM_SHIFTED_PARAMS_Z
- BOOST_PP_ENUM_SHIFTED_z
- BOOST_PP_ENUM_TRAILING_BINARY_PARAMS_Z
- BOOST_PP_ENUM_TRAILING_PARAMS_Z
- BOOST_PP_ENUM_TRAILING_z
- BOOST_PP_ENUM_z
- BOOST_PP_REPEAT_FROM_TO_D_z
- BOOST_PP_REPEAT_FROM_TO_z

base

- BOOST_PP_REPEAT_z

© Copyright Edward Diener 2014

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)